@@ -39,9 +39,7 @@ main (int    argc,
     GtkWidget     *window;
     GError        *error;
 
-    bindtextdomain (GETTEXT_PACKAGE, XFCELOCALEDIR);
-    bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-    textdomain (GETTEXT_PACKAGE);
+    xfce_textdomain (GETTEXT_PACKAGE, XFCELOCALEDIR, "UTF-8");
 
     error = NULL;
 
@@ -53,7 +51,7 @@ main (int    argc,
     }
 
     window = gs_theme_window_new ();
-    g_signal_connect (G_OBJECT (window), "delete-event",
+    g_signal_connect (G_OBJECT (window), "destroy",
                       G_CALLBACK (gtk_main_quit), NULL);
 
     g_set_prgname ("popsquares");
