@@ -176,7 +176,8 @@ auth_message_handler (GSAuthMessageStyle   style,
 }
 
 static gboolean
-gs_auth_queued_message_handler (GsAuthMessageHandlerData *data) {
+gs_auth_queued_message_handler (gpointer user_data) {
+    GsAuthMessageHandlerData *data = user_data;
     gboolean res;
 
     if (gs_auth_get_verbose ()) {
@@ -223,7 +224,7 @@ gs_auth_run_message_handler (struct pam_closure  *c,
 
     /* Queue the callback in the gui (the main) thread
      */
-    g_idle_add ((GSourceFunc) gs_auth_queued_message_handler, &data);
+    g_idle_add (gs_auth_queued_message_handler, &data);
 
     if (gs_auth_get_verbose ()) {
         g_message ("Waiting for respose to message style %d: '%s'", style, msg);
@@ -259,7 +260,6 @@ pam_conversation (int                        nmsgs,
         return PAM_CONV_ERR;
     }
 
-    res = TRUE;
     ret = PAM_SUCCESS;
 
     for (replies = 0; replies < nmsgs && ret == PAM_SUCCESS; replies++) {
@@ -317,9 +317,9 @@ pam_conversation (int                        nmsgs,
             } else {
                 int i;
                 for (i = 0; i <= replies; i++) {
-                    free (reply[i].resp);
+                    g_free (reply[i].resp);
                 }
-                free (reply);
+                g_free (reply);
                 reply = NULL;
                 ret = PAM_CONV_ERR;
             }
@@ -455,8 +455,9 @@ set_pam_error (GError **error,
     }
 }
 
-static int
-gs_auth_thread_func (int auth_operation_fd) {
+static gpointer
+gs_auth_thread_func (gpointer data) {
+    int               auth_operation_fd = GPOINTER_TO_INT (data);
     static const int  flags = 0;
     int               status;
     int               status2;
@@ -541,7 +542,7 @@ done:
      */
     close (auth_operation_fd);
 
-    return status;
+    return GINT_TO_POINTER (status);
 }
 
 static gboolean
@@ -558,7 +559,6 @@ gs_auth_pam_verify_user (pam_handle_t *handle,
                          int          *status) {
     GThread    *auth_thread;
     GIOChannel *channel = NULL;
-    guint       watch_id = 0;
     int         auth_operation_fds[2];
     int         auth_status = PAM_AUTH_ERR;
     gboolean    thread_done;
@@ -590,11 +590,11 @@ gs_auth_pam_verify_user (pam_handle_t *handle,
      * of pam authentication.
      */
     thread_done = FALSE;
-    watch_id = g_io_add_watch (channel, G_IO_ERR | G_IO_HUP,
-                               (GIOFunc) gs_auth_loop_quit, &thread_done);
+    g_io_add_watch (channel, G_IO_ERR | G_IO_HUP,
+                    (GIOFunc) gs_auth_loop_quit, &thread_done);
 
     auth_thread = g_thread_new ("auththread",
-                                (GThreadFunc) gs_auth_thread_func,
+                                gs_auth_thread_func,
                                 GINT_TO_POINTER (auth_operation_fds[1]));
 
     if (auth_thread == NULL) {
@@ -619,11 +619,6 @@ gs_auth_pam_verify_user (pam_handle_t *handle,
     auth_status = GPOINTER_TO_INT (g_thread_join (auth_thread));
 
 out:
-    if (watch_id != 0) {
-        // g_source_remove (watch_id);
-        watch_id = 0;
-    }
-
     if (channel != NULL) {
         g_io_channel_unref (channel);
     }
