@@ -242,7 +242,9 @@ static void        color_from_color_array   (XfconfChannel    *channel,
 }
 
 static gboolean
-do_changed (XfceBG *bg) {
+do_changed (gpointer user_data) {
+    XfceBG *bg = user_data;
+
     bg->changed_id = 0;
 
     g_signal_emit (G_OBJECT (bg), signals[CHANGED], 0);
@@ -256,15 +258,12 @@ queue_changed (XfceBG *bg) {
         g_source_remove (bg->changed_id);
     }
 
-    bg->changed_id = g_timeout_add_full (G_PRIORITY_LOW,
-                         100,
-                         (GSourceFunc)do_changed,
-                         bg,
-                         NULL);
+    bg->changed_id = g_timeout_add_full (G_PRIORITY_LOW, 100, do_changed, bg, NULL);
 }
 
 static gboolean
-do_transitioned (XfceBG *bg) {
+do_transitioned (gpointer user_data) {
+    XfceBG *bg = user_data;
     bg->transitioned_id = 0;
 
     if (bg->pixbuf_cache) {
@@ -283,11 +282,7 @@ queue_transitioned (XfceBG *bg) {
         g_source_remove (bg->transitioned_id);
     }
 
-    bg->transitioned_id = g_timeout_add_full (G_PRIORITY_LOW,
-                          100,
-                          (GSourceFunc)do_transitioned,
-                          bg,
-                          NULL);
+    bg->transitioned_id = g_timeout_add_full (G_PRIORITY_LOW, 100, do_transitioned, bg, NULL);
 }
 
 static gchar *
@@ -625,7 +620,7 @@ xfce_bg_set_placement (XfceBG          *bg,
 }
 
 static inline gchar *
-get_wallpaper_cache_dir () {
+get_wallpaper_cache_dir (void) {
     return g_build_filename (g_get_user_cache_dir(), XFCE_BG_CACHE_DIR, NULL);
 }
 
@@ -1313,13 +1308,15 @@ blow_expensive_caches (gpointer data) {
     bg->blow_caches_id = 0;
 
     if (bg->file_cache) {
-        for (list = bg->file_cache; list != NULL; list = list->next) {
-            FileCacheEntry *ent = list->data;
+        for (list = bg->file_cache; list != NULL; ) {
+            /* Avoid use-after-free */
+            GList *item = list;
+            FileCacheEntry *ent = item->data;
+            list = list->next;
 
             if (ent->type == PIXBUF) {
                 file_cache_entry_delete (ent);
-                bg->file_cache = g_list_delete_link (bg->file_cache,
-                                     list);
+                bg->file_cache = g_list_delete_link (bg->file_cache, item);
             }
         }
     }
@@ -1817,6 +1814,9 @@ handle_start_element (GMarkupParseContext  *context,
              strcmp (parser->stack->tail->data, "to") == 0) {
             slide->file2 = g_slist_prepend (slide->file2, size);
         }
+        else {
+            g_free (size);
+        }
     }
     g_queue_push_tail (parser->stack, g_strdup (name));
 }
@@ -1882,13 +1882,14 @@ handle_text (GMarkupParseContext  *context,
              gpointer              user_data,
              GError              **err) {
     SlideShow *parser = user_data;
+    Slide     *slide;
     FileSize  *fs;
     gint       i;
 
     g_return_if_fail (parser != NULL);
     g_return_if_fail (parser->slides != NULL);
 
-    Slide *slide = parser->slides->tail ? parser->slides->tail->data : NULL;
+    slide = parser->slides->tail ? parser->slides->tail->data : NULL;
 
     if (stack_is (parser, "year", "starttime", "background", NULL)) {
         parser->start_tm.tm_year = parse_int (text) - 1900;
@@ -1996,10 +1997,7 @@ slideshow_unref (SlideShow *show) {
     }
 
     g_queue_free (show->slides);
-
-    g_list_foreach (show->stack->head, (GFunc) g_free, NULL);
-    g_queue_free (show->stack);
-
+    g_queue_free_full (show->stack, g_free);
     g_free (show);
 }
 
