@@ -37,6 +37,11 @@ gboolean xfce_gdk_spawn_command_line_on_screen (GdkScreen    *screen,
                                                 const gchar  *command,
                                                 GError      **error);
 
+gchar  **spawn_make_environment_for_display    (GdkDisplay   *display,
+                                                gchar       **envp);
+
+void     widget_set_best_visual                (GtkWidget    *widget);
+
 G_END_DECLS
 
 #endif /* SRC_XFCE_DESKTOP_UTILS_H_ */
