@@ -118,7 +118,7 @@ static void response_ok(void) {
     fflush(stdout);
 }
 
-static gboolean quit_response_ok(void) {
+static gboolean quit_response_ok(gpointer user_data) {
     response_ok();
     gtk_main_quit();
     return FALSE;
@@ -286,7 +286,8 @@ static gboolean auth_message_handler(GSAuthMessageStyle   style,
     return ret;
 }
 
-static gboolean reset_idle_cb(GSLockPlug* plug) {
+static gboolean reset_idle_cb(gpointer user_data) {
+    GSLockPlug* plug = user_data;
     gs_lock_plug_set_sensitive(plug, TRUE);
     gs_lock_plug_show_message(plug, NULL);
 
@@ -329,18 +330,19 @@ static void response_cb(GSLockPlug *plug,
     }
 }
 
-static gboolean response_request_quit(void) {
+static gboolean response_request_quit(gpointer user_data) {
     printf("REQUEST QUIT\n");
     fflush(stdout);
     return FALSE;
 }
 
-static gboolean quit_timeout_cb(gpointer data) {
+static gboolean quit_timeout_cb(gpointer user_data) {
     gtk_main_quit();
     return FALSE;
 }
 
-static gboolean auth_check_idle(GSLockPlug* plug) {
+static gboolean auth_check_idle(gpointer user_data) {
+    GSLockPlug* plug = user_data;
     gboolean     res;
     gboolean     again;
     static guint loop_counter = 0;
@@ -350,21 +352,21 @@ static gboolean auth_check_idle(GSLockPlug* plug) {
 
     if (res) {
         again = FALSE;
-        g_idle_add((GSourceFunc) quit_response_ok, NULL);
+        g_idle_add(quit_response_ok, NULL);
     } else {
         loop_counter++;
 
         if (loop_counter < MAX_FAILURES) {
             gs_debug ("Authentication failed, retrying (%u)", loop_counter);
-            g_timeout_add_seconds (3, (GSourceFunc) reset_idle_cb, plug);
+            g_timeout_add_seconds (3, reset_idle_cb, plug);
         } else {
             gs_debug ("Authentication failed, quitting (max failures)");
             again = FALSE;
             /* Don't quit immediately, but rather request that xfce4-screensaver
              * terminates us after it has finished the dialog shake. Time out
              * after 5 seconds and quit anyway if this doesn't happen though */
-            g_idle_add((GSourceFunc) response_request_quit, NULL);
-            g_timeout_add_seconds(5, (GSourceFunc) quit_timeout_cb, NULL);
+            g_idle_add(response_request_quit, NULL);
+            g_timeout_add_seconds(5, quit_timeout_cb, NULL);
         }
     }
 
@@ -376,7 +378,7 @@ static void show_cb(GtkWidget *widget,
     print_id(widget);
 }
 
-static gboolean popup_dialog_idle(void) {
+static gboolean popup_dialog_idle(gpointer user_data) {
     GtkWidget      *widget;
     GtkCssProvider *css_provider;
 
@@ -418,7 +420,7 @@ static gboolean popup_dialog_idle(void) {
     gtk_widget_realize(widget);
     gtk_widget_show(widget);
 
-    g_idle_add((GSourceFunc) auth_check_idle, widget);
+    g_idle_add(auth_check_idle, widget);
 
     gs_profile_end(NULL);
 
@@ -436,7 +438,7 @@ static gboolean popup_dialog_idle(void) {
 */
 static gboolean privileged_initialization(int       *argc,
                                           char     **argv,
-                                          gboolean   verbose) {
+                                          gboolean   local_verbose) {
     gboolean  ret;
     char     *nolock_reason;
     char     *orig_uid;
@@ -455,7 +457,7 @@ static gboolean privileged_initialization(int       *argc,
         g_debug("Locking disabled: %s", nolock_reason);
     }
 
-    if (uid_message && verbose) {
+    if (uid_message && local_verbose) {
         g_print("Modified UID: %s", uid_message);
     }
 
@@ -478,7 +480,7 @@ static gboolean privileged_initialization(int       *argc,
 static gboolean lock_initialization (int       *argc,
                                      char     **argv,
                                      char     **nolock_reason,
-                                     gboolean   verbose) {
+                                     gboolean   local_verbose) {
     if (nolock_reason != NULL) {
         *nolock_reason = NULL;
     }
@@ -542,13 +544,7 @@ int main(int    argc,
     GError *error = NULL;
     char   *nolock_reason = NULL;
 
-    #ifdef ENABLE_NLS
-        bindtextdomain(GETTEXT_PACKAGE, XFCELOCALEDIR);
-        #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-            bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
-        #endif
-        textdomain(GETTEXT_PACKAGE);
-    #endif
+    xfce_textdomain (GETTEXT_PACKAGE, XFCELOCALEDIR, "UTF-8");
 
     gs_profile_start(NULL);
 
@@ -592,12 +588,13 @@ int main(int    argc,
 
     gs_debug_init(verbose, FALSE);
 
-    g_idle_add((GSourceFunc) popup_dialog_idle, NULL);
+    g_idle_add(popup_dialog_idle, NULL);
 
     gtk_main();
 
     gs_profile_end(NULL);
     gs_debug_shutdown();
+    xfconf_shutdown ();
 
     return 0;
 }
